<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <meta http-equiv="X-UA-Compatible" content="IE=edge" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta name="csrf-token" content="{{ csrf_token }}">
    <title>Masonite 4</title>
    <link rel="shortcut icon" href="/favicon.ico">
    <link
      href="https://unpkg.com/tailwindcss@^2/dist/tailwind.min.css"
      rel="stylesheet"
    />
    
    <!-- <link rel="stylesheet" href="/assets/css/app.css"> -->
    
  </head>
  <body>
    
    
    <!-- <script src="/assets/js/app.js"></script> -->
    
  </body>
</html>
